==> blender_2.33a.orig.tar.gz: blender-2.33a/source/blender/imbuf/intern/IMB_png.h <==
/*
 * IMB_png.h
 *
 * $Id: IMB_png.h,v 1.7 2003/12/04 18:18:05 sirdude Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */
/**
 * \file IMB_png.h
 * \ingroup imbuf
 * \brief Function declarations for png.c
 */

#ifndef IMB_PNG_H
#define IMB_PNG_H

struct ImBuf;

int imb_is_a_png(void *buf);
struct ImBuf *imb_loadpng(unsigned char *mem, int size, int flags);

short imb_savepng(struct ImBuf *ibuf, int file, int flags);

#endif

==> blender_2.42a.orig.tar.gz: blender-2.42a/source/blender/imbuf/intern/IMB_png.h <==
/*
 * IMB_png.h
 *
 * $Id: IMB_png.h,v 1.8 2004/12/09 13:09:11 sirdude Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */
/**
 * \file IMB_png.h
 * \ingroup imbuf
 * \brief Function declarations for png.c
 */

#ifndef IMB_PNG_H
#define IMB_PNG_H

struct ImBuf;

int imb_is_a_png(void *buf);
struct ImBuf *imb_loadpng(unsigned char *mem, int size, int flags);

short imb_savepng(struct ImBuf *ibuf, char *name, int flags);

#endif
